@@ -1686,9 +1686,9 @@ class Update(MethodsInterface):
                     if self.compare_update_level(binhost.level) > 0:
                         self.set_migration_mode(True)
                     #TODO translate
-                    raise UpdateError(
+                    raise UpdateError((
                         _("Current binhost {} has wrong update level. Current level: {} Binhost level: {}").\
-                                format(binhost_url, self.clVars.Get("update.cl_update_level"), binhost.level, ))
+                                format(binhost_url, self.clVars.Get("update.cl_update_level"), binhost.level)))
 
         if self.binhosts_data.gpg:
             packages_fn = self.clVars.Get('update.cl_update_package_cache')
@@ -1752,8 +1752,8 @@ class Update(MethodsInterface):
                 if cmpr > 0:
                     self.set_migration_mode(True)
                     #TODO reformulate, add translation
-                    raise UpdateError(_("Current level: {} Binhost level: {}".\
-                        format(self.clVars.Get("update.cl_update_level"), best_binhost_level)))
+                    raise UpdateError(_("Current level: {} Binhost level: {}").\
+                        format(self.clVars.Get("update.cl_update_level"), best_binhost_level))
                 if cmpr < 0:
                     # self.clVars.Delete('update.cl_update_binhost_host', location="system")
                     #self.clVars.Get("update.cl_update_binhost_host")
