@@ -986,7 +986,7 @@ class VariableClUpdateProfileUrl(Variable):
             raise VariableError(str(e))
         if not self.Get(self.profiles_shortname):
             raise VariableError(_("Repository %s has no profiles") %
-                value.encode('utf-8'))
+                value)
 
     def get(self):
         try:
